From f0dd558fe520530f4d2950250d9f2081dd232ae7 Mon Sep 17 00:00:00 2001
From: Raghav Gururajan <raghavgururajan@disroot.org>
Date: Wed, 1 Apr 2020 20:42:33 -0400
Subject: [PATCH 10/10] gnu: Add belle-sip

* gnu/packages/linphone.scm (belle-sip): New variable.
---
 gnu/packages/linphone.scm | 33 +++++++++++++++++++++++++++++++++
 1 file changed, 33 insertions(+)

diff --git a/gnu/packages/linphone.scm b/gnu/packages/linphone.scm
index ce3ffa763b..71f23794e2 100644
--- a/gnu/packages/linphone.scm
+++ b/gnu/packages/linphone.scm
@@ -22,11 +22,13 @@
   #:use-module (gnu packages admin)
   #:use-module (gnu packages audio)
   #:use-module (gnu packages base)
+  #:use-module (gnu packages compression)
   #:use-module (gnu packages documentation)
   #:use-module (gnu packages gl)
   #:use-module (gnu packages gnome)
   #:use-module (gnu packages graphviz)
   #:use-module (gnu packages image)
+  #:use-module (gnu packages java)
   #:use-module (gnu packages linux)
   #:use-module (gnu packages pulseaudio)
   #:use-module (gnu packages python)
@@ -335,3 +337,34 @@ is responsible for receiving and sending all multimedia streams in Linphone,
 including media capture, encoding and decoding, and rendering.")
     (home-page "https://gitlab.linphone.org/BC/public/mediastreamer2")
     (license license:gpl2+)))
+
+(define-public belle-sip
+  (package
+    (name "belle-sip")
+    (version "1.6.3")
+    (source
+     (origin
+       (method url-fetch)
+       (uri
+        (string-append "https://www.linphone.org/releases/sources/" name
+                       "/" name "-" version ".tar.gz"))
+       (sha256
+        (base32 "0s55kggmgxap54dkw5856bgk4xg7yvbzialpxnjm0zhpic3hff1z"))))
+    (build-system cmake-build-system)
+    (arguments
+     `(#:tests? #f                      ; Requires network access
+       #:configure-flags
+       (list
+        "-DENABLE_STATIC=NO")))
+    (inputs
+     `(("antlr3" ,antlr3-3.3)
+       ("antlr3c" ,libantlr3c)
+       ("bctoolbox" ,bctoolbox)
+       ("java" ,icedtea)
+       ("zlib" ,zlib)))
+    (synopsis "Belledonne Communications SIP Library")
+    (description "Belle-sip is a modern library implementing SIP transport,
+transaction and dialog layers.  It is written in C, with an object-oriented
+API.  It also comprises a simple HTTP/HTTPS client implementation.")
+    (home-page "https://gitlab.linphone.org/BC/public/belle-sip")
+    (license license:gpl2+)))
-- 
2.26.0

